@@ -32,7 +32,8 @@ def assemble(lines):
                 for token in tokens[1:]:
                     token_type, value = token
                     if token_type == 'register' and value == hot_register:
-                        tokenized_lines.insert(i, ([('operator', 'nop')], ''))
+                        tokenized_lines.insert(
+                            i, (-1, ([('operator', 'nop')], '')))
                         hot_register = None
 
     # simple label pass
